pub fn generate_trivial_test_data<F: Field, const NUM_IRIS_4_CHUNKS: usize, const PARTY_IDX: usize>() -> (MPCCircuitConstData<F>, MPCCircuitInputData<F>)Expand description
create test data for mpc circuits, control the size of such
pub fn generate_trivial_test_data<F: Field, const NUM_IRIS_4_CHUNKS: usize, const PARTY_IDX: usize>() -> (MPCCircuitConstData<F>, MPCCircuitInputData<F>)create test data for mpc circuits, control the size of such